# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## Copyright (C) 2007-2009 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------
"""
"""
from base import *

class IGetConfig(Interface):
    returns=ListOfParameter(element=DictParameter(attrs={
                "name"  : StringParameter(),
                "config": StringParameter(),
            })) | StringParameter()
